## BaseAmisModel

### 继承基类

- #### [Pydantic BaseModel](https://pydantic-docs.helpmanual.io/usage/models/)

### 方法:

#### amis_json

- 返回模型`json`数据,使用字段别名并且排除`None`.

#### amis_dict

- 返回模型`dict`数据,使用字段别名并且排除`None`.

#### update_from_dict

- 通过`dict`更新模型数据.

#### update_from_kwargs

- 通过`kwargs`参数列表更新模型数据.

## AmisNode

参考: [SchemaNode](https://baidu.gitee.io/amis/zh-CN/docs/types/schemanode)

## AmisAPI

参考: [API](https://baidu.gitee.io/amis/zh-CN/docs/types/api)

## Page

参考: [Page 页面](https://baidu.gitee.io/amis/zh-CN/components/page)

## App

参考: [App 多页应用](https://baidu.gitee.io/amis/zh-CN/components/app)

## PageSchema

参考: [App 多页应用](https://baidu.gitee.io/amis/zh-CN/components/app)

## Action

参考: [Action 行为按钮](https://baidu.gitee.io/amis/zh-CN/components/action)

## Form

参考: [Form 表单](https://baidu.gitee.io/amis/zh-CN/components/form/index)

## FormItem

参考: [FormItem 普通表单项](https://baidu.gitee.io/amis/zh-CN/components/form/formitem)

## TableCRUD

参考: [CRUD 增删改查](https://baidu.gitee.io/amis/zh-CN/components/crud)
, [Table 表格](https://baidu.gitee.io/amis/zh-CN/components/table?page=1)

## TableColumn

参考: [Table 表格](https://baidu.gitee.io/amis/zh-CN/components/table?page=1)

## components

参考: [组件介绍](https://baidu.gitee.io/amis/zh-CN/components/index)

## 更多

参考: [Amis官方文档](https://baidu.gitee.io/amis/zh-CN/docs/index)



